#[non_exhaustive]pub struct CustomModelTransformParameters {
pub source_s3_directory_path: String,
pub transform_entry_point_script: Option<String>,
}Expand description
Contains custom model transform parameters. See Use a trained model to generate new model artifacts.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_s3_directory_path: StringThe path to the Amazon S3 location where the Python module implementing your model is located. This must point to a valid existing Amazon S3 location that contains, at a minimum, a training script, a transform script, and a model-hpo-configuration.json file.
transform_entry_point_script: Option<String>The name of the entry point in your module of a script that should be run after the best model from the hyperparameter search has been identified, to compute the model artifacts necessary for model deployment. It should be able to run with no command-line arguments. The default is transform.py.
Implementations
Sourceimpl CustomModelTransformParameters
impl CustomModelTransformParameters
Sourcepub fn source_s3_directory_path(&self) -> &str
pub fn source_s3_directory_path(&self) -> &str
The path to the Amazon S3 location where the Python module implementing your model is located. This must point to a valid existing Amazon S3 location that contains, at a minimum, a training script, a transform script, and a model-hpo-configuration.json file.
Sourcepub fn transform_entry_point_script(&self) -> Option<&str>
pub fn transform_entry_point_script(&self) -> Option<&str>
The name of the entry point in your module of a script that should be run after the best model from the hyperparameter search has been identified, to compute the model artifacts necessary for model deployment. It should be able to run with no command-line arguments. The default is transform.py.
Sourceimpl CustomModelTransformParameters
impl CustomModelTransformParameters
Sourcepub fn builder() -> CustomModelTransformParametersBuilder
pub fn builder() -> CustomModelTransformParametersBuilder
Creates a new builder-style object to manufacture CustomModelTransformParameters.